@@ -38,7 +38,7 @@ dist="gaussian", linkinv, full_model=FALSE, ...)
                 "poisson"=poisson(link),
                 "binomial"=binomial(link))
             mod <- if (dist == "gaussian" && link == "identity") {
-                stats::lm(Y ~ .-1, data=XX, family=Family, ...)
+                stats::lm(Y ~ .-1, data=XX, ...)
             } else {
                 stats::glm(Y ~ .-1, data=XX, family=Family, ...)
             }
@@ -143,6 +143,10 @@ dist="gaussian", linkinv, full_model=FALSE, ...)
         }
         if (!linkinv)
             linv <- NULL
+        ## this should set logLik to a very low but numerically safe number
+        ## handles issue of perfect fit in examples
+        if (getOption("ocoptions")$robust_loglik && (is.na(ll) || is.infinite(ll)))
+            ll <- (-(.Machine$double.xmax^(1/3)))
         out <- list(coef=cf, logLik=ll, linkinv=linv)
     } else {
         if (full_model)
