@@ -11,7 +11,8 @@
             check_comb=TRUE,
             try_error=FALSE,
             scale=0.5,
-            fix_fitted=FALSE))
+            fix_fitted=FALSE,
+            robust_loglik=TRUE))
     options("pboptions" = list(
         type = if (interactive()) "timer" else "none",
         char = "[=-]",
